A Metric counts individual observations from an event or sample stream
in configurable buckets. Similar to a Summary,
it also provides a sum of observations and an observation count.
A Collector that bundles a set of Gauges that all share
the same Desc, but have different values for their variable labels. This is
used if you want to count the same thing partitioned by various dimensions
(e.g. number of operations queued, partitioned by user and operation type).
A Collector that bundles a set of Histograms that all share the
same Desc, but have different values for their variable labels. This is used
if you want to count the same thing partitioned by various dimensions
(e.g. HTTP request latencies, partitioned by status code and method).